#
# spec file for package local-npm-registry
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           local-npm-registry
Version:        1.1.0
Release:        150600.3.6.1
Summary:        Localhost-only version of NPM registry
License:        GPL-3.0-or-later
URL:            https://github.com/openSUSE/npm-localhost-proxy
Source:         https://github.com/openSUSE/npm-localhost-proxy/releases/download/v%{version}/local_npm_registry-v%{version}.tar.gz
Requires:       npm-default
BuildArch:      noarch

%description
localhost-only npm registry serves NPM packages on localhost
address allowing running of "npm install" in a non-networked
environment

%prep
%autosetup -p1 -n local_npm_registry-v%{version}

%build
# nothing to build, or we end up in a build cycle of 1

%install
mkdir -p %{buildroot}%{_datadir}/%{name}
mkdir -p %{buildroot}%{_bindir}
cp -r dist node_modules %{buildroot}%{_datadir}/%{name}
cat > %{buildroot}%{_bindir}/local-npm-registry << EOF
#!/usr/bin/node
(async () => {
  const foo = await import("%{_datadir}/%{name}/dist/index.js");
  foo.mainEntryFunction();
})();
EOF

%files
%defattr(-,root,root)
%license COPYING
%doc README.md
%attr(755,root,root) %{_bindir}/local-npm-registry
%{_datadir}/%{name}

%changelog
* Wed Feb 26 2025 doreilly@suse.com
- fix await import error on older node.js versions
* Fri Feb 21 2025 adam.majer@suse.de
- update to 1.1.0
  * always run npm with --no-package-lock. This will fix all weird
    errors and no loger require cleaning package-lock.json from
    upstream
  * `quilt setup` script is now in the utility
  * everything is run in JS now, so you can run directly with
    node version of change. Either,
    local-npm-registry
    or
    node22 /usr/bin/local-npm-registry
* Tue Jan 30 2024 adam.majer@suse.de
- update to 1.0.2
  * --help invocation fixes
  * cleanup npm's config.registry on exit
  * adds support for non-standard alternative versions
* Fri Dec 29 2023 adam.majer@suse.de
- Escape `quilt setup` invoked section in the helper script
* Fri Jul 21 2023 adam.majer@suse.de
- update to 1.0.1
  * update dependencies
  * no longer shows paths for tarballs served by the proxy
  * works with latest nodejs
- 0001-Allow-the-user-to-provide-their-own-npm-command-by-m.patch:
  dropped, upstreamed
* Tue Aug 16 2022 adam.majer@suse.de
- Revert Requires: back to npm-default. If we need support for
  Fedora to have something else, we can do this another way
  https://en.opensuse.org/openSUSE:Build_Service_prjconf#Substitute
* Mon Aug 15 2022 brunopitrus@hotmail.com
- Allow the user to override `node` and `npm` commands in PATH.
  This is useful if one wants to eg. use Electron to run npm.
  * add 0001-Allow-the-user-to-provide-their-own-npm-command-by-m.patch
- Change Requires: npm-default to Requires: npm.
  npm-default is already prefered by the prjconf,
  this works with any version of npm,
  and Fedora does not have npm-default.
* Wed Aug 11 2021 adam.majer@suse.de
- update to 0.0.3:
  * fixes case when npm is stalling when package is not found
* Tue Jan 26 2021 adam.majer@suse.de
- Update to 0.0.2: fixes uncaught exceptions
- work with quilt when unpacking archive
* Mon Jan 18 2021 adam.majer@suse.de
- Initial version 0.0.1
